![Title](/assets/title.png)

[![Discord](https://img.shields.io/discord/1139873703556034620?label=discord)](https://discord.gg/RnRTjq24vX)
[![GitHub Repo stars](https://img.shields.io/github/stars/t0rnato/scute?label=stars)](https://github.com/T0RNATO/scute)
[![PyPI](https://img.shields.io/pypi/v/scute)
![PyPI - Downloads](https://img.shields.io/pypi/dm/scute)](https://pypi.org/project/scutemc/)

A simple Python library for creating Minecraft datapacks with Python. (Very much in development)

[Read the docs](https://t0rnato.github.io/scute),
[view on PyPi](https://pypi.org/project/scutemc/), or
[join the Discord](https://discord.gg/RnRTjq24vX) for support.